@@ -7,9 +7,14 @@ import re
 import uuid
 from asyncio import Future
 from typing import Awaitable, Optional, Union
+import ddtrace
 
 from simple_api_framework.monitors import DataDogMonitor
 
+if os.getenv("DD_SERVICE") and os.getenv("DD_API_KEY") and os.getenv("DD_API_KEY") and os.getenv("DD_ENV"):
+    ddtrace.patch(tornado=True)
+    ddtrace.patch_all()
+
 import dotenv
 import magic
 import sentry_sdk
